.. _iop4lib:


Reference
=========

:code:`iop4lib` is the module at the core of IOP4.

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

##################

.. automodule:: iop4lib
   :members:

   iop4lib.config
   ==============
   Configuration and initialization of iop4lib.

   .. automodule:: iop4lib.config
      :members:

   iop4lib.db
   ==========
   Models for the database.

   .. automodule:: iop4lib.db.epoch
      :members:

   .. automodule:: iop4lib.db.rawfit
      :members:

   .. automodule:: iop4lib.db.masterbias
      :members:

   .. automodule:: iop4lib.db.masterflat
      :members:

   .. automodule:: iop4lib.db.reducedfit
      :members:

   .. automodule:: iop4lib.db.astrosource
      :members:

   .. automodule:: iop4lib.db.photopolresult
      :members:

   .. automodule:: iop4lib.db.aperphotresult
      :members:


   iop4lib.utils
   =============
   Utility functions, used thoughout the code.

   .. automodule:: iop4lib.utils.sourcedetection
      :members:

   .. automodule:: iop4lib.utils.sourcepairing
      :members:

   .. automodule:: iop4lib.utils.astrometry
      :members:

   .. automodule:: iop4lib.utils.parallel
      :members:

   iop4lib.telescopes
   ==================
   Telescope specific code.

   .. automodule:: iop4lib.telescopes
      :members:

   .. automodule:: iop4lib.telescopes.telescope
      :members:

   .. automodule:: iop4lib.telescopes.osnt090
      :members:

   .. automodule:: iop4lib.telescopes.cahat220
      :members:

   iop4lib.instruments
   ===================
   Instrument specific code.

   .. automodule:: iop4lib.instruments
      :members: